@@ -28,4 +28,8 @@ NULL
 #' Nse force
 #'
 #' @importFrom rlang !!
-NULL
\ No newline at end of file
+NULL
+
+#' Shiny input
+utils::globalVariables("input")
+
