@@ -1,17 +1,3 @@
-# other
-
-#' @title A4 useable width.
-#' @description The width of useable space within an a4 sheet.
-#' @return A numeric value.
-#' @export
-a4_width_mm <- 170
-
-#' @title A4 useable height.
-#' @description The height of useable space within an a4 sheet.
-#' @return A numeric value.
-#' @export
-a4_height_mm <- 257
-
 #' @title Add a quick tooltip text column to data.
 #' @description Add a column of tooltip text which is automatically created based on column names and values. 
 #' @param data A tibble or dataframe. Required input.
@@ -81,7 +67,7 @@ mutate_text <- function(data, vars_vctr = NULL, comma = FALSE) {
   }
   
   data <- data %>%
-    dplyr::mutate(text = stringr::str_replace_all(text, "NA", "Not available"))
+    dplyr::mutate(text = stringr::str_replace_all(text, " NA<br>", " Not available<br>"))
   
   return(data)
 }
