@@ -13,7 +13,8 @@ library(simplevis)
 data1 <- ggplot2::diamonds %>% 
   slice_sample(prop = 0.1)
 
-data2 <- simplevis::example_sf_point
+data2 <- simplevis::example_sf_point %>% 
+  mutate(trend_category = factor(trend_category, levels = c("Improving", "Indeterminate", "Worsening")))
 
 # add helper vectors (if required)
 color_vector <- sort(unique(data1$color))
