@@ -10,21 +10,22 @@ data_folder <- "inst/shiny/template2/data/"
 
 data1 <-  readRDS(paste0(data_folder, "data1.RDS"))
 
-data2 <-  readRDS(paste0(data_folder, "data2.RDS"))
+data2 <-  readRDS(paste0(data_folder, "data2.RDS")) %>% 
+  mutate(trend_category = factor(trend_category, levels = c("Improving", "Indeterminate", "Worsening")))
 
 # make a plot filtered by a user selected colour
 color_vector <- sort(unique(data1$color))
 
 selected_color <- "E"
 
-plot_data <- data %>%
+plot_data <- data1 %>%
   filter(color == selected_color) %>% 
   mutate(cut = stringr::str_to_sentence(cut)) %>%
   group_by(cut, clarity, .drop = FALSE) %>%
   summarise(average_price = round(mean(price), 0)) %>%
   mutate(average_price_thousands = round(average_price / 1000, 1)) %>%
   mutate(average_price = paste0("US$", prettyNum(average_price,  big.mark = ","))) %>% 
-  add_tip(c("cut", "clarity", "average_price"))
+  mutate_text(c("cut", "clarity", "average_price"))
 
 title <- paste0("Average diamond price of colour ", selected_color, " by cut and clarity")
 x_title <- "Average price ($US thousands)"
@@ -34,8 +35,8 @@ plot <- ggplot_hbar_col(data = plot_data,
                         x_var = average_price_thousands, 
                         y_var = cut, 
                         col_var = clarity,
-                        tip_var = tip_text,
-                        legend_ncol = 4,
+                        text_var = text,
+                        col_ncol = 4,
                         title = title, 
                         x_title = x_title, 
                         y_title = y_title)
@@ -44,21 +45,23 @@ plotly::ggplotly(plot, tooltip = "text") %>%
   plotly_camera() 
 
 # make a trend map filtered by a user selected metric
-metric_vector <- sort(unique(data2$indicator))
 
-selected_metric <- "Nitrate-nitrogen"
+map_filter <- "Worsening"
 
-map_data <- data2 %>%
-  filter(period == "2008-2017") %>% 
-  filter(indicator == selected_metric)
+if(map_filter == "None") {
+  map_data <- data2 
+} else if(map_filter != "None") {
+  map_data <- data2 %>% 
+    filter(trend_category == map_filter)
+}
 
 pal <- c("#4575B4", "#D3D3D3", "#D73027")
+names(pal) <- c("Improving", "Indeterminate", "Worsening")
 
-title <- paste0("Monitored river ", selected_metric, " trends, 2008\u201317")
+title <- paste0("Monitored trends, 2008\u201317")
 
 leaflet_sf_col(map_data, 
                trend_category, 
                pal = pal, 
-               col_method = "category",
                title = title)
 
