@@ -19,10 +19,11 @@ shinyServer(function(input, output, session) {
       summarise(average_price = round(mean(price), 0)) %>%
       mutate(average_price_thousands = round(average_price / 1000, 1)) %>%
       mutate(average_price = paste0("US$", prettyNum(average_price,  big.mark = ","))) %>% 
-      add_tip(c("cut", "clarity", "average_price"))
+      mutate_text(c("cut", "clarity", "average_price"))
     
     return(plot_data)
-  })
+  }) %>% 
+    bindCache(input$plot_color)
   
   plot <- reactive({ # create a reactive ggplot object
     
@@ -40,26 +41,28 @@ shinyServer(function(input, output, session) {
                             x_var = average_price_thousands, 
                             y_var = cut, 
                             col_var = clarity,
-                            tip_var = tip_text,
-                            legend_ncol = 4,
+                            text_var = text,
+                            col_labels_ncol = 4,
                             title = title, 
                             x_title = x_title, 
                             y_title = y_title,
-                            isMobile = input$isMobile)
+                            mobile = input$isMobile)
     
     
     return(plot)
-  })
+  }) %>% 
+    bindCache(input$plot_color)
   
   output$plot_desktop <- plotly::renderPlotly({ 
     plotly::ggplotly(plot(), tooltip = "text") %>%
       plotly_camera() 
-
-  })
+  }) %>% 
+    bindCache(input$plot_color)
   
   output$plot_mobile <- renderPlot({
     plot() 
-  })
+  }) %>% 
+    bindCache(input$plot_color)
   
   ### table ###
   
@@ -86,4 +89,16 @@ shinyServer(function(input, output, session) {
     contentType = "application/zip"
   )
   
+  ### download code ###
+  
+  output$download_code <- downloadHandler(
+    filename <- function() {
+      "template1.zip"
+    },
+    content <- function(file) {
+      file.copy("data/template1.zip", file)
+    },
+    contentType = "application/zip"
+  )
+  
 })
